@@ -8,7 +8,7 @@ use Net::SSL;
 use warnings;
 use strict;
 
-$API::PureStorage::VERSION = '0.02';
+$API::PureStorage::VERSION = '0.03';
 
 our %ENV;
 $ENV{PERL_LWP_SSL_VERIFY_HOSTNAME} = 0;
@@ -64,7 +64,7 @@ sub new {
 
 sub DESTROY {
   my $self = shift @_;
-  my $ret = $self->{client}->DELETE("/api/$self->{api_version}/auth/session");
+  my $ret = $self->{client}->DELETE("/api/$self->{api_version}/auth/session") if defined $self->{api_version};
   unlink $self->{cookie_file};
 }
 
@@ -76,6 +76,13 @@ sub array_info {
     return wantarray ? @$ref : $ref;
 }
 
+sub volume_detail {
+    my $self = shift @_;
+    my $name = shift @_;
+    my $ref = $self->_api_get("/api/$self->{api_version}/volume/".$name);
+    return wantarray ? @$ref : $ref;
+}
+
 sub volume_info {
     my $self = shift @_;
     my $ref = $self->_api_get("/api/$self->{api_version}/volume?space=true");
@@ -138,6 +145,14 @@ API::PureStorage - Interacting with Pure Storage devices
 
   print "The array $host is currently $percent full\n";
 
+  print "\nVolumes on host $host:\n";
+
+  my $vol_info = $pure->volume_info();
+  for my $vol (sort { lc($a->{name}) cmp lc($b->{name}) } @$vol_info) {
+    my $detail = $pure->volume_detail($vol->{name});
+    print join("\t", $detail->{name}, $detail->{serial}, $detail->{created}), "\n";
+  }
+
 =head1 DESCRIPTION
 
 This module is a wrapper around the Pure Storage API for their devices.
@@ -185,8 +200,8 @@ NB: To calculate the percentage usage of whole array, divide total by capacity.
 
 =head2 volume_info()
 
-    my @volume_info = $pure->volume_info()
-    my $volume_info_ref = $pure->volume_info()
+    my @volume_info = $pure->volume_info();
+    my $volume_info_ref = $pure->volume_info();
 
 Returns an array or arrayref of general information about volumes include space
 usage.
@@ -217,10 +232,26 @@ Volume space usage info:
 
 NB: To calculate the percentage usage of the volume, divide total by size.
 
+=head2 volume_detail($volume_name)
+
+    my %volume_detail = $pure->volume_detail($volume_name);
+    my $volume_detail_ref = $pure->volume_detail($volume_name);
+
+Returns a hash or hasref (depending on requested context) of additional
+information on the volumes now shown in the vol_info() summary.
+
+=head3 Hash data reference:
+
+* created - A time stamp from when the volume was created
+* name - the name of the volume
+* serial - the serial number of the volume
+* size - Size of the volume in bytes
+* source - the source of this volume if it was cloned from a snapshot or other volume
+
 =head2 version()
 
-    my @versions = $pure->version()
-    my $versions_ref = $pure->version()
+    my @versions = $pure->version();
+    my $versions_ref = $pure->version();
 
 Returns an array/arrayref of API versions supported by the storage array.
 
@@ -238,7 +269,7 @@ Returns an array/arrayref of API versions supported by the storage array.
 	
 =head1 VERSION
 
-	API::PureStorage v0.02 (2016/07/01)
+	API::PureStorage v0.03 (2016/07/01)
 
 =head1 COPYRIGHT
 
